# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/rapidai',
                'doc_host': 'https://m-gopichand.github.io',
                'git_url': 'https://github.com/m-gopichand/rapidai',
                'lib_path': 'rapidai'},
  'syms': { 'rapidai.accel': { 'rapidai.accel.AccelerateCB': ('ddpm_v2.html#acceleratecb', 'rapidai/accel.py'),
                               'rapidai.accel.AccelerateCB.__init__': ('ddpm_v2.html#acceleratecb.__init__', 'rapidai/accel.py'),
                               'rapidai.accel.AccelerateCB.backward': ('ddpm_v2.html#acceleratecb.backward', 'rapidai/accel.py'),
                               'rapidai.accel.AccelerateCB.before_fit': ('ddpm_v2.html#acceleratecb.before_fit', 'rapidai/accel.py'),
                               'rapidai.accel.MixedPrecision': ('ddpm_v2.html#mixedprecision', 'rapidai/accel.py'),
                               'rapidai.accel.MixedPrecision.after_loss': ('ddpm_v2.html#mixedprecision.after_loss', 'rapidai/accel.py'),
                               'rapidai.accel.MixedPrecision.backward': ('ddpm_v2.html#mixedprecision.backward', 'rapidai/accel.py'),
                               'rapidai.accel.MixedPrecision.before_batch': ( 'ddpm_v2.html#mixedprecision.before_batch',
                                                                              'rapidai/accel.py'),
                               'rapidai.accel.MixedPrecision.before_fit': ('ddpm_v2.html#mixedprecision.before_fit', 'rapidai/accel.py'),
                               'rapidai.accel.MixedPrecision.step': ('ddpm_v2.html#mixedprecision.step', 'rapidai/accel.py')},
            'rapidai.activations': { 'rapidai.activations.ActivationStats': ('activations.html#activationstats', 'rapidai/activations.py'),
                                     'rapidai.activations.ActivationStats.__init__': ( 'activations.html#activationstats.__init__',
                                                                                       'rapidai/activations.py'),
                                     'rapidai.activations.ActivationStats.color_dim': ( 'activations.html#activationstats.color_dim',
                                                                                        'rapidai/activations.py'),
                                     'rapidai.activations.ActivationStats.dead_chart': ( 'activations.html#activationstats.dead_chart',
                                                                                         'rapidai/activations.py'),
                                     'rapidai.activations.ActivationStats.plot_stats': ( 'activations.html#activationstats.plot_stats',
                                                                                         'rapidai/activations.py'),
                                     'rapidai.activations.Hook': ('activations.html#hook', 'rapidai/activations.py'),
                                     'rapidai.activations.Hook.__del__': ('activations.html#hook.__del__', 'rapidai/activations.py'),
                                     'rapidai.activations.Hook.__init__': ('activations.html#hook.__init__', 'rapidai/activations.py'),
                                     'rapidai.activations.Hook.remove': ('activations.html#hook.remove', 'rapidai/activations.py'),
                                     'rapidai.activations.Hooks': ('activations.html#hooks', 'rapidai/activations.py'),
                                     'rapidai.activations.Hooks.__del__': ('activations.html#hooks.__del__', 'rapidai/activations.py'),
                                     'rapidai.activations.Hooks.__delitem__': ( 'activations.html#hooks.__delitem__',
                                                                                'rapidai/activations.py'),
                                     'rapidai.activations.Hooks.__enter__': ('activations.html#hooks.__enter__', 'rapidai/activations.py'),
                                     'rapidai.activations.Hooks.__exit__': ('activations.html#hooks.__exit__', 'rapidai/activations.py'),
                                     'rapidai.activations.Hooks.__init__': ('activations.html#hooks.__init__', 'rapidai/activations.py'),
                                     'rapidai.activations.Hooks.remove': ('activations.html#hooks.remove', 'rapidai/activations.py'),
                                     'rapidai.activations.HooksCallback': ('activations.html#hookscallback', 'rapidai/activations.py'),
                                     'rapidai.activations.HooksCallback.__init__': ( 'activations.html#hookscallback.__init__',
                                                                                     'rapidai/activations.py'),
                                     'rapidai.activations.HooksCallback.__iter__': ( 'activations.html#hookscallback.__iter__',
                                                                                     'rapidai/activations.py'),
                                     'rapidai.activations.HooksCallback.__len__': ( 'activations.html#hookscallback.__len__',
                                                                                    'rapidai/activations.py'),
                                     'rapidai.activations.HooksCallback._hookfunc': ( 'activations.html#hookscallback._hookfunc',
                                                                                      'rapidai/activations.py'),
                                     'rapidai.activations.HooksCallback.after_fit': ( 'activations.html#hookscallback.after_fit',
                                                                                      'rapidai/activations.py'),
                                     'rapidai.activations.HooksCallback.before_fit': ( 'activations.html#hookscallback.before_fit',
                                                                                       'rapidai/activations.py'),
                                     'rapidai.activations.append_stats': ('activations.html#append_stats', 'rapidai/activations.py'),
                                     'rapidai.activations.get_hist': ('activations.html#get_hist', 'rapidai/activations.py'),
                                     'rapidai.activations.get_min': ('activations.html#get_min', 'rapidai/activations.py'),
                                     'rapidai.activations.set_seed': ('activations.html#set_seed', 'rapidai/activations.py')},
            'rapidai.augment': { 'rapidai.augment.CapturePreds': ('augment.html#capturepreds', 'rapidai/augment.py'),
                                 'rapidai.augment.CapturePreds.after_batch': ( 'augment.html#capturepreds.after_batch',
                                                                               'rapidai/augment.py'),
                                 'rapidai.augment.CapturePreds.after_fit': ('augment.html#capturepreds.after_fit', 'rapidai/augment.py'),
                                 'rapidai.augment.CapturePreds.before_fit': ('augment.html#capturepreds.before_fit', 'rapidai/augment.py'),
                                 'rapidai.augment.RandCopy': ('augment.html#randcopy', 'rapidai/augment.py'),
                                 'rapidai.augment.RandCopy.__init__': ('augment.html#randcopy.__init__', 'rapidai/augment.py'),
                                 'rapidai.augment.RandCopy.forward': ('augment.html#randcopy.forward', 'rapidai/augment.py'),
                                 'rapidai.augment.RandErase': ('augment.html#randerase', 'rapidai/augment.py'),
                                 'rapidai.augment.RandErase.__init__': ('augment.html#randerase.__init__', 'rapidai/augment.py'),
                                 'rapidai.augment.RandErase.forward': ('augment.html#randerase.forward', 'rapidai/augment.py'),
                                 'rapidai.augment._flops': ('augment.html#_flops', 'rapidai/augment.py'),
                                 'rapidai.augment._rand_copy1': ('augment.html#_rand_copy1', 'rapidai/augment.py'),
                                 'rapidai.augment._rand_erase1': ('augment.html#_rand_erase1', 'rapidai/augment.py'),
                                 'rapidai.augment.capture_preds': ('augment.html#capture_preds', 'rapidai/augment.py'),
                                 'rapidai.augment.rand_copy': ('augment.html#rand_copy', 'rapidai/augment.py'),
                                 'rapidai.augment.rand_erase': ('augment.html#rand_erase', 'rapidai/augment.py'),
                                 'rapidai.augment.show_image_batch': ('augment.html#show_image_batch', 'rapidai/augment.py'),
                                 'rapidai.augment.summary': ('augment.html#summary', 'rapidai/augment.py')},
            'rapidai.conv': { 'rapidai.conv.collate_device': ('convolutions.html#collate_device', 'rapidai/conv.py'),
                              'rapidai.conv.conv': ('convolutions.html#conv', 'rapidai/conv.py'),
                              'rapidai.conv.device': ('convolutions.html#device', 'rapidai/conv.py'),
                              'rapidai.conv.to_device': ('convolutions.html#to_device', 'rapidai/conv.py')},
            'rapidai.core': {'rapidai.core.foo': ('core.html#foo', 'rapidai/core.py')},
            'rapidai.datasets': { 'rapidai.datasets.DataLoaders': ('datasets.html#dataloaders', 'rapidai/datasets.py'),
                                  'rapidai.datasets.DataLoaders.__init__': ('datasets.html#dataloaders.__init__', 'rapidai/datasets.py'),
                                  'rapidai.datasets.DataLoaders.from_dd': ('datasets.html#dataloaders.from_dd', 'rapidai/datasets.py'),
                                  'rapidai.datasets.collate_dict': ('datasets.html#collate_dict', 'rapidai/datasets.py'),
                                  'rapidai.datasets.get_grid': ('datasets.html#get_grid', 'rapidai/datasets.py'),
                                  'rapidai.datasets.inplace': ('datasets.html#inplace', 'rapidai/datasets.py'),
                                  'rapidai.datasets.show_image': ('datasets.html#show_image', 'rapidai/datasets.py'),
                                  'rapidai.datasets.show_images': ('datasets.html#show_images', 'rapidai/datasets.py'),
                                  'rapidai.datasets.subplots': ('datasets.html#subplots', 'rapidai/datasets.py')},
            'rapidai.diffusion': { 'rapidai.diffusion.DownBlock': ('diffusion-attn-cond.html#downblock', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.DownBlock.__init__': ( 'diffusion-attn-cond.html#downblock.__init__',
                                                                             'rapidai/diffusion.py'),
                                   'rapidai.diffusion.DownBlock.forward': ( 'diffusion-attn-cond.html#downblock.forward',
                                                                            'rapidai/diffusion.py'),
                                   'rapidai.diffusion.EmbResBlock': ('diffusion-attn-cond.html#embresblock', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.EmbResBlock.__init__': ( 'diffusion-attn-cond.html#embresblock.__init__',
                                                                               'rapidai/diffusion.py'),
                                   'rapidai.diffusion.EmbResBlock.forward': ( 'diffusion-attn-cond.html#embresblock.forward',
                                                                              'rapidai/diffusion.py'),
                                   'rapidai.diffusion.EmbUNetModel': ('diffusion-attn-cond.html#embunetmodel', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.EmbUNetModel.__init__': ( 'diffusion-attn-cond.html#embunetmodel.__init__',
                                                                                'rapidai/diffusion.py'),
                                   'rapidai.diffusion.EmbUNetModel.forward': ( 'diffusion-attn-cond.html#embunetmodel.forward',
                                                                               'rapidai/diffusion.py'),
                                   'rapidai.diffusion.SelfAttention': ('diffusion-attn-cond.html#selfattention', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.SelfAttention.__init__': ( 'diffusion-attn-cond.html#selfattention.__init__',
                                                                                 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.SelfAttention.forward': ( 'diffusion-attn-cond.html#selfattention.forward',
                                                                                'rapidai/diffusion.py'),
                                   'rapidai.diffusion.SelfAttention2D': ( 'diffusion-attn-cond.html#selfattention2d',
                                                                          'rapidai/diffusion.py'),
                                   'rapidai.diffusion.SelfAttention2D.forward': ( 'diffusion-attn-cond.html#selfattention2d.forward',
                                                                                  'rapidai/diffusion.py'),
                                   'rapidai.diffusion.UpBlock': ('diffusion-attn-cond.html#upblock', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.UpBlock.__init__': ( 'diffusion-attn-cond.html#upblock.__init__',
                                                                           'rapidai/diffusion.py'),
                                   'rapidai.diffusion.UpBlock.forward': ( 'diffusion-attn-cond.html#upblock.forward',
                                                                          'rapidai/diffusion.py'),
                                   'rapidai.diffusion.abar': ('diffusion-attn-cond.html#abar', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.collate_ddpm': ('diffusion-attn-cond.html#collate_ddpm', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.cond_sample': ('diffusion-attn-cond.html#cond_sample', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.ddim_step': ('diffusion-attn-cond.html#ddim_step', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.dl_ddpm': ('diffusion-attn-cond.html#dl_ddpm', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.inv_abar': ('diffusion-attn-cond.html#inv_abar', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.lin': ('diffusion-attn-cond.html#lin', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.noisify': ('diffusion-attn-cond.html#noisify', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.pre_conv': ('diffusion-attn-cond.html#pre_conv', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.sample': ('diffusion-attn-cond.html#sample', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.saved': ('diffusion-attn-cond.html#saved', 'rapidai/diffusion.py'),
                                   'rapidai.diffusion.timestep_embedding': ( 'diffusion-attn-cond.html#timestep_embedding',
                                                                             'rapidai/diffusion.py'),
                                   'rapidai.diffusion.upsample': ('diffusion-attn-cond.html#upsample', 'rapidai/diffusion.py')},
            'rapidai.fid': { 'rapidai.fid.ImageEval': ('fid.html#imageeval', 'rapidai/fid.py'),
                             'rapidai.fid.ImageEval.__init__': ('fid.html#imageeval.__init__', 'rapidai/fid.py'),
                             'rapidai.fid.ImageEval.fid': ('fid.html#imageeval.fid', 'rapidai/fid.py'),
                             'rapidai.fid.ImageEval.get_feats': ('fid.html#imageeval.get_feats', 'rapidai/fid.py'),
                             'rapidai.fid.ImageEval.kid': ('fid.html#imageeval.kid', 'rapidai/fid.py'),
                             'rapidai.fid._calc_fid': ('fid.html#_calc_fid', 'rapidai/fid.py'),
                             'rapidai.fid._calc_kid': ('fid.html#_calc_kid', 'rapidai/fid.py'),
                             'rapidai.fid._calc_stats': ('fid.html#_calc_stats', 'rapidai/fid.py'),
                             'rapidai.fid._sqrtm_newton_schulz': ('fid.html#_sqrtm_newton_schulz', 'rapidai/fid.py'),
                             'rapidai.fid._squared_mmd': ('fid.html#_squared_mmd', 'rapidai/fid.py')},
            'rapidai.imports': {},
            'rapidai.init': { 'rapidai.init.BatchTransformCB': ('initializing.html#batchtransformcb', 'rapidai/init.py'),
                              'rapidai.init.BatchTransformCB.__init__': ('initializing.html#batchtransformcb.__init__', 'rapidai/init.py'),
                              'rapidai.init.BatchTransformCB.before_batch': ( 'initializing.html#batchtransformcb.before_batch',
                                                                              'rapidai/init.py'),
                              'rapidai.init.GeneralRelu': ('initializing.html#generalrelu', 'rapidai/init.py'),
                              'rapidai.init.GeneralRelu.__init__': ('initializing.html#generalrelu.__init__', 'rapidai/init.py'),
                              'rapidai.init.GeneralRelu.forward': ('initializing.html#generalrelu.forward', 'rapidai/init.py'),
                              'rapidai.init._lsuv_stats': ('initializing.html#_lsuv_stats', 'rapidai/init.py'),
                              'rapidai.init.clean_ipython_hist': ('initializing.html#clean_ipython_hist', 'rapidai/init.py'),
                              'rapidai.init.clean_mem': ('initializing.html#clean_mem', 'rapidai/init.py'),
                              'rapidai.init.clean_tb': ('initializing.html#clean_tb', 'rapidai/init.py'),
                              'rapidai.init.conv': ('initializing.html#conv', 'rapidai/init.py'),
                              'rapidai.init.get_model': ('initializing.html#get_model', 'rapidai/init.py'),
                              'rapidai.init.init_weights': ('initializing.html#init_weights', 'rapidai/init.py'),
                              'rapidai.init.lsuv_init': ('initializing.html#lsuv_init', 'rapidai/init.py'),
                              'rapidai.init.plot_func': ('initializing.html#plot_func', 'rapidai/init.py')},
            'rapidai.learner': { 'rapidai.learner.Callback': ('learner.html#callback', 'rapidai/learner.py'),
                                 'rapidai.learner.CancelBatchException': ('learner.html#cancelbatchexception', 'rapidai/learner.py'),
                                 'rapidai.learner.CancelEpochException': ('learner.html#cancelepochexception', 'rapidai/learner.py'),
                                 'rapidai.learner.CancelFitException': ('learner.html#cancelfitexception', 'rapidai/learner.py'),
                                 'rapidai.learner.DeviceCB': ('learner.html#devicecb', 'rapidai/learner.py'),
                                 'rapidai.learner.DeviceCB.__init__': ('learner.html#devicecb.__init__', 'rapidai/learner.py'),
                                 'rapidai.learner.DeviceCB.before_batch': ('learner.html#devicecb.before_batch', 'rapidai/learner.py'),
                                 'rapidai.learner.DeviceCB.before_fit': ('learner.html#devicecb.before_fit', 'rapidai/learner.py'),
                                 'rapidai.learner.LRFinderCB': ('learner.html#lrfindercb', 'rapidai/learner.py'),
                                 'rapidai.learner.LRFinderCB.__init__': ('learner.html#lrfindercb.__init__', 'rapidai/learner.py'),
                                 'rapidai.learner.LRFinderCB.after_batch': ('learner.html#lrfindercb.after_batch', 'rapidai/learner.py'),
                                 'rapidai.learner.LRFinderCB.before_fit': ('learner.html#lrfindercb.before_fit', 'rapidai/learner.py'),
                                 'rapidai.learner.LRFinderCB.cleanup_fit': ('learner.html#lrfindercb.cleanup_fit', 'rapidai/learner.py'),
                                 'rapidai.learner.Learner': ('learner.html#learner', 'rapidai/learner.py'),
                                 'rapidai.learner.Learner.__getattr__': ('learner.html#learner.__getattr__', 'rapidai/learner.py'),
                                 'rapidai.learner.Learner.__init__': ('learner.html#learner.__init__', 'rapidai/learner.py'),
                                 'rapidai.learner.Learner._fit': ('learner.html#learner._fit', 'rapidai/learner.py'),
                                 'rapidai.learner.Learner._one_batch': ('learner.html#learner._one_batch', 'rapidai/learner.py'),
                                 'rapidai.learner.Learner._one_epoch': ('learner.html#learner._one_epoch', 'rapidai/learner.py'),
                                 'rapidai.learner.Learner.callback': ('learner.html#learner.callback', 'rapidai/learner.py'),
                                 'rapidai.learner.Learner.fit': ('learner.html#learner.fit', 'rapidai/learner.py'),
                                 'rapidai.learner.Learner.one_epoch': ('learner.html#learner.one_epoch', 'rapidai/learner.py'),
                                 'rapidai.learner.Learner.training': ('learner.html#learner.training', 'rapidai/learner.py'),
                                 'rapidai.learner.MLflowCallback': ('learner.html#mlflowcallback', 'rapidai/learner.py'),
                                 'rapidai.learner.MLflowCallback.__init__': ('learner.html#mlflowcallback.__init__', 'rapidai/learner.py'),
                                 'rapidai.learner.MLflowCallback.after_batch': ( 'learner.html#mlflowcallback.after_batch',
                                                                                 'rapidai/learner.py'),
                                 'rapidai.learner.MLflowCallback.after_epoch': ( 'learner.html#mlflowcallback.after_epoch',
                                                                                 'rapidai/learner.py'),
                                 'rapidai.learner.MLflowCallback.after_fit': ( 'learner.html#mlflowcallback.after_fit',
                                                                               'rapidai/learner.py'),
                                 'rapidai.learner.MLflowCallback.before_fit': ( 'learner.html#mlflowcallback.before_fit',
                                                                                'rapidai/learner.py'),
                                 'rapidai.learner.MetricsCB': ('learner.html#metricscb', 'rapidai/learner.py'),
                                 'rapidai.learner.MetricsCB.__init__': ('learner.html#metricscb.__init__', 'rapidai/learner.py'),
                                 'rapidai.learner.MetricsCB._log': ('learner.html#metricscb._log', 'rapidai/learner.py'),
                                 'rapidai.learner.MetricsCB.after_batch': ('learner.html#metricscb.after_batch', 'rapidai/learner.py'),
                                 'rapidai.learner.MetricsCB.after_epoch': ('learner.html#metricscb.after_epoch', 'rapidai/learner.py'),
                                 'rapidai.learner.MetricsCB.before_epoch': ('learner.html#metricscb.before_epoch', 'rapidai/learner.py'),
                                 'rapidai.learner.MetricsCB.before_fit': ('learner.html#metricscb.before_fit', 'rapidai/learner.py'),
                                 'rapidai.learner.MomentumLearner': ('learner.html#momentumlearner', 'rapidai/learner.py'),
                                 'rapidai.learner.MomentumLearner.__init__': ( 'learner.html#momentumlearner.__init__',
                                                                               'rapidai/learner.py'),
                                 'rapidai.learner.MomentumLearner.zero_grad': ( 'learner.html#momentumlearner.zero_grad',
                                                                                'rapidai/learner.py'),
                                 'rapidai.learner.ProgressCB': ('learner.html#progresscb', 'rapidai/learner.py'),
                                 'rapidai.learner.ProgressCB.__init__': ('learner.html#progresscb.__init__', 'rapidai/learner.py'),
                                 'rapidai.learner.ProgressCB._log': ('learner.html#progresscb._log', 'rapidai/learner.py'),
                                 'rapidai.learner.ProgressCB.after_batch': ('learner.html#progresscb.after_batch', 'rapidai/learner.py'),
                                 'rapidai.learner.ProgressCB.after_epoch': ('learner.html#progresscb.after_epoch', 'rapidai/learner.py'),
                                 'rapidai.learner.ProgressCB.before_epoch': ('learner.html#progresscb.before_epoch', 'rapidai/learner.py'),
                                 'rapidai.learner.ProgressCB.before_fit': ('learner.html#progresscb.before_fit', 'rapidai/learner.py'),
                                 'rapidai.learner.SingleBatchCB': ('learner.html#singlebatchcb', 'rapidai/learner.py'),
                                 'rapidai.learner.SingleBatchCB.after_batch': ( 'learner.html#singlebatchcb.after_batch',
                                                                                'rapidai/learner.py'),
                                 'rapidai.learner.TrainCB': ('learner.html#traincb', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainCB.__init__': ('learner.html#traincb.__init__', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainCB.backward': ('learner.html#traincb.backward', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainCB.get_loss': ('learner.html#traincb.get_loss', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainCB.predict': ('learner.html#traincb.predict', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainCB.step': ('learner.html#traincb.step', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainCB.zero_grad': ('learner.html#traincb.zero_grad', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainLearner': ('learner.html#trainlearner', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainLearner.backward': ('learner.html#trainlearner.backward', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainLearner.get_loss': ('learner.html#trainlearner.get_loss', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainLearner.predict': ('learner.html#trainlearner.predict', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainLearner.step': ('learner.html#trainlearner.step', 'rapidai/learner.py'),
                                 'rapidai.learner.TrainLearner.zero_grad': ('learner.html#trainlearner.zero_grad', 'rapidai/learner.py'),
                                 'rapidai.learner.WandbCallback': ('learner.html#wandbcallback', 'rapidai/learner.py'),
                                 'rapidai.learner.WandbCallback.__init__': ('learner.html#wandbcallback.__init__', 'rapidai/learner.py'),
                                 'rapidai.learner.WandbCallback.after_batch': ( 'learner.html#wandbcallback.after_batch',
                                                                                'rapidai/learner.py'),
                                 'rapidai.learner.WandbCallback.after_epoch': ( 'learner.html#wandbcallback.after_epoch',
                                                                                'rapidai/learner.py'),
                                 'rapidai.learner.WandbCallback.after_fit': ('learner.html#wandbcallback.after_fit', 'rapidai/learner.py'),
                                 'rapidai.learner.WandbCallback.before_fit': ( 'learner.html#wandbcallback.before_fit',
                                                                               'rapidai/learner.py'),
                                 'rapidai.learner.lr_find': ('learner.html#lr_find', 'rapidai/learner.py'),
                                 'rapidai.learner.run_cbs': ('learner.html#run_cbs', 'rapidai/learner.py'),
                                 'rapidai.learner.to_cpu': ('learner.html#to_cpu', 'rapidai/learner.py'),
                                 'rapidai.learner.with_cbs': ('learner.html#with_cbs', 'rapidai/learner.py'),
                                 'rapidai.learner.with_cbs.__call__': ('learner.html#with_cbs.__call__', 'rapidai/learner.py'),
                                 'rapidai.learner.with_cbs.__init__': ('learner.html#with_cbs.__init__', 'rapidai/learner.py')},
            'rapidai.resnet': { 'rapidai.resnet.ResBlock': ('resnet.html#resblock', 'rapidai/resnet.py'),
                                'rapidai.resnet.ResBlock.__init__': ('resnet.html#resblock.__init__', 'rapidai/resnet.py'),
                                'rapidai.resnet.ResBlock.forward': ('resnet.html#resblock.forward', 'rapidai/resnet.py'),
                                'rapidai.resnet._conv_block': ('resnet.html#_conv_block', 'rapidai/resnet.py')},
            'rapidai.sgd': { 'rapidai.sgd.BaseSchedCB': ('accel_sgd.html#baseschedcb', 'rapidai/sgd.py'),
                             'rapidai.sgd.BaseSchedCB.__init__': ('accel_sgd.html#baseschedcb.__init__', 'rapidai/sgd.py'),
                             'rapidai.sgd.BaseSchedCB._step': ('accel_sgd.html#baseschedcb._step', 'rapidai/sgd.py'),
                             'rapidai.sgd.BaseSchedCB.before_fit': ('accel_sgd.html#baseschedcb.before_fit', 'rapidai/sgd.py'),
                             'rapidai.sgd.BatchSchedCB': ('accel_sgd.html#batchschedcb', 'rapidai/sgd.py'),
                             'rapidai.sgd.BatchSchedCB.after_batch': ('accel_sgd.html#batchschedcb.after_batch', 'rapidai/sgd.py'),
                             'rapidai.sgd.EpochSchedCB': ('accel_sgd.html#epochschedcb', 'rapidai/sgd.py'),
                             'rapidai.sgd.EpochSchedCB.after_epoch': ('accel_sgd.html#epochschedcb.after_epoch', 'rapidai/sgd.py'),
                             'rapidai.sgd.HasLearnCB': ('accel_sgd.html#haslearncb', 'rapidai/sgd.py'),
                             'rapidai.sgd.HasLearnCB.after_fit': ('accel_sgd.html#haslearncb.after_fit', 'rapidai/sgd.py'),
                             'rapidai.sgd.HasLearnCB.before_fit': ('accel_sgd.html#haslearncb.before_fit', 'rapidai/sgd.py'),
                             'rapidai.sgd.RecorderCB': ('accel_sgd.html#recordercb', 'rapidai/sgd.py'),
                             'rapidai.sgd.RecorderCB.__init__': ('accel_sgd.html#recordercb.__init__', 'rapidai/sgd.py'),
                             'rapidai.sgd.RecorderCB.after_batch': ('accel_sgd.html#recordercb.after_batch', 'rapidai/sgd.py'),
                             'rapidai.sgd.RecorderCB.before_fit': ('accel_sgd.html#recordercb.before_fit', 'rapidai/sgd.py'),
                             'rapidai.sgd.RecorderCB.plot': ('accel_sgd.html#recordercb.plot', 'rapidai/sgd.py')},
            'rapidai.training': { 'rapidai.training.Dataset': ('minibatch_training.html#dataset', 'rapidai/training.py'),
                                  'rapidai.training.Dataset.__getitem__': ( 'minibatch_training.html#dataset.__getitem__',
                                                                            'rapidai/training.py'),
                                  'rapidai.training.Dataset.__init__': ('minibatch_training.html#dataset.__init__', 'rapidai/training.py'),
                                  'rapidai.training.Dataset.__len__': ('minibatch_training.html#dataset.__len__', 'rapidai/training.py'),
                                  'rapidai.training.accuracy': ('minibatch_training.html#accuracy', 'rapidai/training.py'),
                                  'rapidai.training.fit': ('minibatch_training.html#fit', 'rapidai/training.py'),
                                  'rapidai.training.get_dls': ('minibatch_training.html#get_dls', 'rapidai/training.py'),
                                  'rapidai.training.report': ('minibatch_training.html#report', 'rapidai/training.py')}}}
